@@ -30,6 +30,15 @@ class TrailerLot:
         ]
         self.content = Row.setStructs(structs=structs, content=self.content)
 
+    def setSumOfValuesNonBarCodeTax(self, sum, otherSum, additionSum, totalSum):
+        structs = [
+            (23, 37, 14, numeric, sum),                     # Soma dos valores principais dos lotes
+            (37, 51, 14, numeric, otherSum),                # Soma dos valores outras entidades dos lotes
+            (51, 65, 14, numeric, additionSum),             # Soma dos valores acréscimos dos lotes
+            (65, 79, 14, numeric, totalSum),                # Soma dos valores totais dos lotes
+        ]
+        self.content = Row.setStructs(structs=structs, content=self.content)
+
     def setSenderBank(self, bank):
         structs = [
             (0, 3, 3, numeric, bank.bankId),                   # Código do banco debitado
